clear
set more off

capture mkdir ./Datasets

*Imports all spreadsheets - renames a few variables that appear for both regions and Spain, 
*to differentiate them so the datasets can be merged

*Starts with sets of regional-level data sheets
forvalues ca=1/17{
	insheet using budget`ca'_im.csv
	gen rincome = 1000*operacionesnofinancieras 
	gen rspending = 1000*v25 
	gen rdeficit = 1000*deficit
	gen totalinc = 1000*totalingresos
	gen rtrans = 1000*v5 
	save ./Datasets/budget`ca'.dta, replace
	clear
}

forvalues ca=1/17{
	insheet using gdp`ca'_im.csv
	gen region = `ca'
	gen rgdp = 1000*gdp
	save ./Datasets/gdp`ca'.dta, replace
	clear
}

forvalues ca=1/17{
	insheet using politics`ca'_im.csv
	save ./Datasets/politics`ca'.dta, replace
	clear
}

forvalues ca=1/17{
	insheet using pop`ca'_im.csv
	rename population rpop
	save ./Datasets/pop`ca'.dta, replace
	clear
}

forvalues ca=1/17{
	forvalues yr=2002/2010{
		insheet using spend_`ca'_`yr'.csv
		save ./Datasets/spend_`ca'_`yr'.dta, replace
		clear
	}
}

*Create discretionary and non-discretionary variables and drop all extraneous variables so these datasets can be merged*
forvalues ca=1/17{
	forvalues yr=2002/2004{
		use ./Datasets/spend_`ca'_`yr'.dta
		gen disc = 1000*(serviciosdecarctergeneral + proteccincivilyseguridadciudadan + seguridadyproteccincivil + produccindebienespblicosdecarcte - educacin + produccindebienesdecarctereconmi + regulacineconmicadecarctergenera + regulacineconmicadesectoresprodu)
		gen totspend = 1000*totalgastos 
		gen nondisc = totspend - disc
		keep year totspend disc nondisc
		save ./Datasets/spend_`ca'_`yr'.dta, replace
		clear
	}
}

forvalues ca=1/17{
	forvalues yr=2005/2010{
		use ./Datasets/spend_`ca'_`yr'.dta
		gen totspend = 1000*totalgastos 
		gen disc = 1000*(serviciospblicosbsicos + actuacionesdeproteccinypromocins + produccindebienespblicosdecarcte - sanidad + actuacionesdecarctereconmico + altadireccin + serviciosdecarctergeneral + administracinfinancieraytributar)
		gen nondisc = totspend - disc
		keep year totspend disc nondisc
		save ./Datasets/spend_`ca'_`yr'.dta, replace
		clear
	}
}
			

*Import national-level data sheets
insheet using budgetesp_im.csv
	gen ndeficit = 1000*deficit 
	gen nspending = 1000*spending 
	save ./Datasets/budgetesp.dta, replace
	clear

insheet using gdpesp_im.csv
	gen ngdp = 1000000*gdp
	drop gdp
	save ./Datasets/gdpesp.dta, replace
	clear
	
insheet using interest_im.csv
	save ./Datasets/interest.dta, replace
	clear
	
insheet using popesp_im.csv
	rename population npop
	save ./Datasets/popesp.dta, replace
	clear

insheet using inflation_im.csv
	rename annualinflation inflation
	rename priceindex19801 pindex
	save ./Datasets/inflation, replace
	clear

insheet using politicsesp_im.csv
	save ./Datasets/politicsesp, replace
	clear
	
