clear
set more off

*Merge all datasets pertaining to one province, by year

capture mkdir ./Datasets

forvalues ca=1/17{
	use ./Datasets/spend_`ca'_2002.dta
	

	append using ./Datasets/spend_`ca'_2003.dta ./Datasets/spend_`ca'_2004.dta ./Datasets/spend_`ca'_2005.dta ./Datasets/spend_`ca'_2006.dta ./Datasets/spend_`ca'_2007.dta ./Datasets/spend_`ca'_2008.dta ./Datasets/spend_`ca'_2009.dta ./Datasets/spend_`ca'_2010.dta
	drop if year==.
	
	save ./Datasets/spend`ca'.dta, replace
}

forvalues ca=1/17{
	use ./Datasets/budget`ca'.dta
	
	global types ./Datasets/gdp`ca' ./Datasets/politics`ca' ./Datasets/pop`ca' ./Datasets/spend`ca' ./Datasets/budgetesp ./Datasets/gdpesp ./Datasets/interest ./Datasets/popesp ./Datasets/inflation ./Datasets/politicsesp
	
	foreach type in $types{
		merge 1:1 year using `type'.dta, nogen
	}
	
	save ./Datasets/region`ca'data.dta, replace
}

clear




*Append all provinces together
	
use ./Datasets/region1data.dta

forvalues ca=2/17{
	append using ./Datasets/region`ca'data.dta
}	

save final.dta, replace


*Generate a few variables (set some figures in terms of GDP, others in per-capita terms)

gen rgdpcap = (rgdp/rpop)/pindex
gen ngdpcap = (ngdp/npop)/pindex

gen rdefgdp = 100*(-rdeficit/rgdp)
gen ndefgdp = 100*(-ndeficit/ngdp)

gen rspendgdp = 100*(rspending/rgdp)
gen nspendgdp = 100*(nspending/ngdp)
gen rincgdp = 100*(rincome/rgdp)

sort region year
by region: gen rgdpgrowth = 100*((rgdp/pindex)-(rgdp[_n-1]/pindex[_n-1]))/(rgdp[_n-1]/pindex[_n-1])
gen rgdpgrowthl1=rgdpgrowth[_n-1]
gen rgdpgrowthl2=rgdpgrowth[_n-2]
gen rgdpgrowthl3=rgdpgrowth[_n-3]


*Generate variables having to do with discretionary versus non-discretionary spending and transfer income

gen disctot = 100*(disc/totspend)

gen discgdp = 100*(disc/rgdp)

gen discfunds = 100*(disc/(totalinc-(totspend-disc)))

gen transgdp = 100*(rtrans/rgdp)
gen transtot = 100*(rtrans/totalinc)

*Dummy variables equal 1 after important events in the history of Spanish federalism

gen euro = 0
	replace euro = 1 if year >= 1999
	
gen post02 = 0
	replace post02 = 1 if year >= 2002
	
gen bsl = 0
	replace bsl = 1 if year >= 2007	
	
gen crisis = 0
	replace crisis = 1 if year >= 2008
	
*Dummy variables equal 1 for unique/interesting groups of Autonomies
	
gen lang = 0
	replace lang = 1 if (region==5 | region==10 | region==12)
	
gen art151 = 0
	replace art151 = 1 if (lang==1 | region==1 | region==6 | region==16 | region==17)

gen foral = 0
	replace foral = 1 if (region==5 | region==16)

*Rename variables from budget, political datasets	
	
rename v5 itransfer

rename winningpartycoalition rparty
gen rpp = 0
	replace rpp = 1 if conservative=="Yes"
	replace rpp = . if conservative=="."
gen rpsoe = 0
	replace rpsoe = 1 if liberal=="Yes"
	replace rpsoe = . if liberal=="."
gen rauto = 0
	replace rauto = 1 if regionalnationalist=="Yes"
	replace rauto = . if regionalnationalist=="."
gen rcons = 0
	replace rcons = 1 if conservativenonationalists=="Yes"
	replace rcons = . if conservativenonationalists=="."
gen rlib = 0
	replace rlib = 1 if rcons==0
	replace rlib = . if liberalnonationalists=="."
gen coa = 0
	replace coa = 1 if coalition=="Yes"
	replace coa = . if coalition=="."
gen minority = 0
	replace minority = 1 if minoritygovernment=="Yes"
	replace minority = . if minoritygovernment=="."
rename winnervoteshare vote
gen largest = 0
	replace largest = 1 if winnerlargestvotegetter=="Yes"
	replace largest = . if winnerlargestvotegetter=="."
gen newgovt = 0
	replace newgovt = 1 if firstcycleinpower=="Yes"
	replace newgovt = . if firstcycleinpower=="."
gen elec = 0
	replace elec = 1 if electionyear=="Yes"
	replace elec = . if electionyear=="."
gen elec_3 = 0
	replace elec_3 = 1 if yearafterelection=="Yes"
	replace elec_3 = . if yearafterelection=="."
gen elec_2 = 0
	replace elec_2 = 1 if yearsbeforeelection=="Yes"
	replace elec_2 = . if yearsbeforeelection=="."
gen elec_1 = 0
	replace elec_1 = 1 if yearbeforeelection=="Yes"
	replace elec_1 = . if yearbeforeelection=="."
gen cycle = 1
	replace cycle = 2 if elec_3==1
	replace cycle = 3 if elec_2==1
	replace cycle = 4 if elec_1==1
	replace cycle = . if elec==. | elec_1==. | elec_2==. | elec_3==.

rename interest10yrbond interest
rename inflation inf

*Generate political variables for the national level that correspond with the regional political variables

gen ncons = 0
	replace ncons = 1 if partyinpower=="PP"
	replace ncons = . if partyinpower=="."
gen nlib = 0
	replace nlib = 1 if ncons==0
	replace nlib = . if ncons==.
rename partyinpower nparty

*Generate another dependent variable: whether or not the region was bailed out in 2012
gen bailout = 0
	replace bailout = 1 if (region==1 | region==3 | region==4 | region==6 | region==7 | region==9 | region==10| region==15 | region==17)

*Can't be the best way to do this, but create a variable that actually gives the regions their names
gen regname = "Andalusia"
	replace regname = "Aragon" if region==2
	replace regname = "Asturias" if region==3
	replace regname = "Balearic Islands" if region==4
	replace regname = "Basque Country" if region==5
	replace regname = "Canary Islands" if region==6
	replace regname = "Cantabria" if region==7
	replace regname = "Castile and Leon" if region==8
	replace regname = "Castile-la Mancha" if region==9
	replace regname = "Catalonia" if region==10
	replace regname = "Extremadura" if region==11
	replace regname = "Galicia" if region==12
	replace regname = "La Rioja" if region==13
	replace regname = "Madrid" if region==14
	replace regname = "Murcia" if region==15
	replace regname = "Navarre" if region==16
	replace regname = "Valencia" if region==17
	
drop if year>2011 | year<1983


**Dropping variables I will never use and old versions of variables I have renamed or recoded.

drop nondisc itransfer operacionesnofinancieras v25 totalgastos rspending rdeficit totalinc rtrans gdp rgdp vote rparty rpop disc totspend rincome nondisc spending ndeficit nspending ngdp npop pindex nparty deficit v2 v3 v4 v6 totalingresos operacionescorrientes v8 v9 operacionesdecapital operacionesfinancieras v12 v13 v16 v17 v18 v19 v20 v21 v22 v23 v24 v26 v27 v28 spendingfinalbudget spending1stbudget spendingpaymentsowed v7 v10 v11 conservative liberal regionalnationalist conservativenonationalists liberalnonationalists coalition minoritygovernment winnerlargestvotegetter firstcycleinpower electionyear yearafterelection yearsbeforeelection yearbeforeelection

**Label variables

la var region "Region, numbered 1-17 in alphabetical order"
la var rgdpcap "Regional real GDP-per-capita, Euros (Base year=1980)"
la var ngdpcap "Spanish real GDP-per-capita, Euros (Base year=1980)"
la var rdefgdp "Regional deficit/regional GDP ratio, %"
la var ndefgdp "Federal deficit/GDP ratio, %"
la var rspendgdp "Regional expenditures/regional GDP ratio, %"
la var nspendgdp "Federal expenditures/GDP ratio, %"
la var rincgdp "Regional revenues/regional GDP ratio, %"
la var rgdpgrowth "Regional annual GDP growth, %"
la var rgdpgrowthl1 "Regional annual 1-year lagged GDP growth, %"
la var rgdpgrowthl2 "Regional annual 2-year lagged GDP growth, %"
la var rgdpgrowthl3 "Regional annual 3-year lagged GDP growth, %"
la var disctot "Regional discretionary spending/total spending, %"
la var discgdp "Regional discretionary spending/regional GDP, %"
la var euro "Euro adoption dummy"
la var post02 "2002 tax and spending law dummy"
la var bsl "2007 Budget Stability Law dummy"
la var crisis "2008 crisis dummy"
la var lang "Minority language region dummy"
la var art151 "Region originally subject to Article 151 dummy"
la var foral "Foral tax system dummy"
la var rpp "Regional parliament ruled by PP"
la var rpsoe "Regional parliament ruled by PSOE"
la var rauto "Regional parliament ruled by regionalist party"
la var rcons "Regional parliament ruled by conservative-leaning party"
la var rlib "Regional parliament ruled by liberal-leaning party"
la var coa "Regional government has ruling coalition"
la var minority "Region has minority government"
la var largest "Ruling party won the most votes in last election"
la var newgovt "Ruling party took power in last election"
la var elec "Election year dummy"
la var elec_1 "Year before election dummy"
la var elec_2 "2 Years before election dummy"
la var elec_3 "Year after election dummy"
la var cycle "Point in electoral cycle"
la var ncons "Spanish parliament ruled by PP"
la var nlib "Spanish parliament ruled by PSOE"
la var bailout "Region received bailout in 2010"
la var regname "Region name"
la var transgdp "Regional transfer revenues/regional GDP, %"
la var transtot "Regional transfer revenues/total regional revenues, %"
la var discfunds "Regional discretionary spending/'discretionary funds', %"

capture mkdir ./FinalData
save ./FinalData/final.dta, replace
