/*
THIS DO-FILE IS A SLIGHTLY REVISED VERSION OF THE ONE ETHAN HASWELL
CREATED FOR HIS SENIOR THESIS.
It was modified by Richard Ball on 2016-09-27.
*/

*****DESCRIPTIVE STATISTICS FOR THE THESIS DATA SECTION AND DATA APPENDIX******

********DATA SECTION********

**Political balance of power

clear
use ./FinalData/final.dta
set more off

*FIGURE 3	
*Line graph shows changes in the political balance of power over time
sort year
by year: egen ym_rpp=mean(rpp) if year>=1983 & year<=2012
by year: replace ym_rpp=. if _n>1

by year: egen ym_rpsoe=mean(rpsoe) if year>=1983 & year<=2012
by year: replace ym_rpsoe=. if _n>1

by year: egen ym_rauto=mean(rauto) if year>=1983 & year<=2012
by year: replace ym_rauto=. if _n>1

scatter ym_rpsoe ym_rpp ym_rauto year, c(l l l) s(i i i) lpattern(l - _) title("Political Balance of Power over Time") ytitle("Fraction of regions in power") b1title("Year") legend(label(1 "Liberal") label(2 "Conservative") label(3 "Regionalist")) xlabel(1983(10)2013)


*FIGURE 4
*Bar graph shows percentage of years regions have been ruled by conservative, liberal, or regionalist governments
drop if region==.

graph bar rpsoe rpp rauto, bar(1,fcolor(gs0)) bar(2,fcolor(gs8)) bar(3,fcolor(gs16)) over(regname, label(angle(45))) percentages stack title("Political Leanings by Region") ytitle("Percentage of years in power") b1title("Region") legend(label(1 "Liberal") label(2 "Conservative") label(3 "Regionalist"))


**Deficit/GDP ratio over time


clear
use ./FinalData/final.dta
set more off

*FIGURE 5
*A different way of displaying this: show boxplots of Deficit/GDP each year
sort year

graph box rdefgdp, over(year, label(angle(45))) title("Minimum and Maximum Deficit/GDP each Year") ytitle("Deficit/GDP")

clear
use ./FinalData/final.dta
set more off

*FIGURE 6
*Income/GDP and spending/GDP
sort year
by year: egen ym_rspend=mean(rspendgdp)
by year: replace ym_rspend=. if _n>1

by year: egen ym_rinc=mean(rincgdp)
by year: replace ym_rinc=. if _n>1

scatter ym_rspend ym_rinc year, c(l l) s(i i) lpattern(l -) title("Average Regional Spending/GDP and Income/GDP by Year") ytitle("Ratio") xtitle("Year") xlabel(1983(10)2013) legend(label(1 "Spending/GDP") label(2 "Income/GDP"))


**Spending and Deficits, conservative vs. liberal governments


*FIGURE 7
*Deficits
clear
use ./FinalData/final.dta
set more off

sort year

sum rdefgdp if rcons==1
sum rdefgdp if rlib==1

by year: egen cons_rdef=mean(rdefgdp) if rcons==1

by year: egen lib_rdef=mean(rdefgdp) if rlib==1

scatter lib_rdef cons_rdef year, c(l l) s(i i) lpattern(l -)

*FIGURE 8
*Spending
clear
use ./FinalData/final.dta
set more off

sort year

sum rspendgdp if rcons==1
sum rspendgdp if rlib==1

by year: egen cons_rspend=mean(rspendgdp) if rcons==1

by year: egen lib_rspend=mean(rspendgdp) if rlib==1

scatter lib_rspend cons_rspend year, c(l l) s(i i) lpattern(l -)


*Deficits and GDP growth

*FIGURE 9
**SHOWS THAT REGIONAL DEFICITS TEND TO TRACK REGIONAL GDP GROWTH (WITH HIGHER GROWTH CLOSELY FOLLOWING LOWER DEFICITS, AND LOWER GROWTH CLOSELY FOLLOWING HIGHER DEFICITS)**
clear
use ./FinalData/final.dta
set more off

sort year
by year: egen ym_rdef=mean(-rdefgdp)
by year: replace ym_rdef=. if _n>1

by year: egen ym_rgrowth=mean(rgdpgrowth)
by year: replace ym_rgrowth=. if _n>1

twoway (line ym_rdef year, lpattern(-)) (line ym_rgrowth year, yaxis(2)), title("Average Regional Surplus/GDP and GDP Growth") ytitle("Surplus/GDP", axis(1)) ytitle("GDP Growth", axis(2)) xtitle("Year") xlabel(1983(10)2013) legend(label(1 "Regional Surplus/GDP") label(2 "Avg. Regional GDP Growth"))


*TABLES 1 AND 2
**Different government forms, spending and deficits

clear
use ./FinalData/final.dta
set more off

*Coalitions, deficits
bysort coa: sum rdefgdp

*Coalitions, spending
bysort coa: sum rspendgdp

*Minority governments, deficits
bysort minority: sum rdefgdp

*Minority governments, spending
bysort minority: sum rspendgdp

*Largest party leads the government, deficits
bysort largest: sum rdefgdp

*Largest party leads the government, spending
bysort largest: sum rspendgdp

*New government, deficits
bysort newgovt: sum rdefgdp

*New government, spending
bysort newgovt: sum rspendgdp

*Bailed out, deficits
bysort bailout: sum rdefgdp

*Bailed out, spending
bysort bailout: sum rspendgdp


****LET'S CONCLUDE BY LOOKING AT VARIANCE IN THE DATA - IS IT MORE ACROSS YEARS OR WITHIN YEARS?; MORE ACROSS REGIONS OR WITHIN REGIONS?


**PROGRAM THAT WILL EXAMINE THIS BY YEAR IS CALLED anova_yr**
capture program drop anova_yr
program define anova_yr
clear
use ./FinalData/final.dta
scalar drop _all
quietly sum `1'
scalar define XB_`1'=r(mean)
gen `1'_XB_dev2=(`1'-XB_`1')^2
gen temp=sum(`1'_XB_dev2)
scalar define sst_`1'=temp[_N]
drop temp `1'_XB_dev2
sort year
by year: egen yr_mean_`1'=mean(`1')
gen temp=(yr_mean_`1'-XB_`1')^2
by year: replace temp=. if _n>1
gen temp2=sum(temp)
scalar define ss_across_years_`1'=17*temp2[_N]
drop temp temp2
gen obs_`1'_year_mean_dev2=(`1'-yr_mean_`1')^2
gen temp=sum(obs_`1'_year_mean_dev2)
scalar define ss_within_years=temp[_N]
drop temp
scalar list
end


**PROGRAM THAT WILL EXAMINE THIS BY REGION IS CALLED anova_reg**
capture program drop anova_reg
program define anova_reg
clear
use ./FinalData/final.dta
scalar drop _all
quietly sum `1'
scalar define XB_`1'=r(mean)
gen `1'_XB_dev2=(`1'-XB_`1')^2
gen temp=sum(`1'_XB_dev2)
scalar define sst_`1'=temp[_N]
drop temp `1'_XB_dev2
sort region
by region: egen reg_mean_`1'=mean(`1')
gen temp=(reg_mean_`1'-XB_`1')^2
by region: replace temp=. if _n>1
gen temp2=sum(temp)
scalar define ss_across_regions_`1'=27*temp2[_N]
drop temp temp2
gen obs_`1'_reg_mean_dev2=(`1'-reg_mean_`1')^2
gen temp=sum(obs_`1'_reg_mean_dev2)
scalar define ss_within_regions=temp[_N]
drop temp
scalar list
end


*NOW COMPARING THE RESULTS OF THESE TWO STATISTICAL TESTS FOR A FEW VARIABLES
clear
use ./FinalData/final.dta

*TABLE 3 
anova  rdefgdp region
anova  rdefgdp  year

*TABLE 4
anova rspendgdp region
anova rspendgdp year

anova rgdpcap  region
anova rgdpcap year

anova rgdpgrowth region
anova rgdpgrowth year

anova disctot region
anova disctot year

anova transtot region
anova transtot year

anova rcons region
anova rcons year

anova coa region
anova coa year



*TABLE 6
******A FEW SIMPLE T-TESTS TO ASSESS WHETHER OR NOT LARGE DEFICITS LED TO BAILOUTS
clear
use ./FinalData/final.dta
set more off

ttest rdefgdp if year==2010, by(bailout) unequal
ttest rdefgdp if year>=2007, by(bailout) unequal


ssc install outreg2
**BASIC REGRESSIONS FOR DEFICIT/GDP, USING ONLY VARIABLES THAT VARY WITHIN REGIONS AND WITHIN YEARS, WITH AND WITHOUT REGION FIXED EFFECTS
clear
use ./FinalData/final.dta
set more off

**CHECKING FOR CORRELATION IN INDEPENDENT VARIABLES
corr rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot

*TABLE 7
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rdefgdptable1.doc, replace: reg rdefgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rdefgdptable1.doc, append: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rdefgdptable1.doc, ctitle("rdefgdp w/ Region FE") append: areg rdefgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rdefgdptable1.doc, ctitle("rdefgdp w/ Region FE") append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rdefgdptable1.doc, ctitle("rdefgdp w/ Year FE") append: areg rdefgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(year)
outreg2 using Regression_Output/rdefgdptable1.doc, ctitle("rdefgdp w/ Year FE") append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(year)
outreg2 using Regression_Output/rdefgdptable1.doc, ctitle("rdefgdp, After 2001") append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot disctot if year>=2002, absorb(region)

sum rdefgdp if year<2002

**MIGHT YEAR FIXED EFFECTS BY HIGHLY CORRELATED WITH SOME OF THE ECONOMIC CONTROLS?
corr year rgdpcap rgdpgrowth

**REGRESSIONS INCLUDING VARIABLES THAT VARY BY YEAR BUT NOT BY REGION, WITH REGION FIXED EFFECTS
clear
use ./FinalData/final.dta
set more off

*TABLE 8
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rdefgdptable2.doc, replace: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot interest, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot inf, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ndefgdp, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ncons, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot euro, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot post02, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot bsl, absorb(region)
outreg2 using Regression_Output/rdefgdptable2.doc, append: areg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot crisis, absorb(region)


**REGRESSIONS INCLUDING VARIABLES THAT VARY BY REGION BUT NOT BY YEAR
clear
use ./FinalData/final.dta
set more off

*TABLE 9
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rdefgdptable3.doc, replace: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rdefgdptable3.doc, append: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot lang
outreg2 using Regression_Output/rdefgdptable3.doc, ctitle("rdefgdp, Before 2002") append: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151 if year<2002
outreg2 using Regression_Output/rdefgdptable3.doc, ctitle("rdefgdp, 2002 and later") append: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151 if year>=2002
outreg2 using Regression_Output/rdefgdptable3.doc, append: reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot foral




**BASIC REGRESSIONS FOR SPENDING/GDP, USING ONLY VARIABLES THAT VARY WITHIN REGIONS AND WITHIN YEARS, WITH AND WITHOUT REGION FIXED EFFECTS
clear
use ./FinalData/final.dta
set more off

*TABLE 10
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rspendgdptable1.doc, replace: reg rspendgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rspendgdptable1.doc, append: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rspendgdptable1.doc, ctitle("rspendgdp w/ Region FE") append: areg rspendgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rspendgdptable1.doc, ctitle("rspendgdp w/ Region FE") append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rspendgdptable1.doc, ctitle("rspendgdp w/ Year FE") append: areg rspendgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(year)
outreg2 using Regression_Output/rspendgdptable1.doc, ctitle("rspendgdp w/ Year FE") append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(year)
outreg2 using Regression_Output/rspendgdptable1.doc, ctitle("rspendgdp, After 2002") append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot disctot if year>=2002, absorb(region)

**REGRESSIONS INCLUDING VARIABLES THAT VARY BY YEAR BUT NOT BY REGION, WITH REGION FIXED EFFECTS
clear
use ./FinalData/final.dta
set more off

*TABLE 11
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rspendgdptable2.doc, replace: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot interest, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot inf, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot nspendgdp, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ncons, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot euro, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot post02, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot bsl, absorb(region)
outreg2 using Regression_Output/rspendgdptable2.doc, append: areg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot crisis, absorb(region)


**REGRESSIONS INCLUDING VARIABLES THAT VARY BY REGION BUT NOT BY YEAR
clear
use ./FinalData/final.dta
set more off

*TABLE 12
capture mkdir ./Regression_Output
outreg2 using Regression_Output/rspendgdptable3.doc, replace: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
outreg2 using Regression_Output/rspendgdptable3.doc, append: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot lang
outreg2 using Regression_Output/rspendgdptable3.doc, ctitle("rspendgdp, Before 2002") append: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151 if year<2002
outreg2 using Regression_Output/rspendgdptable3.doc, ctitle("rspendgdp, 2002 and later") append: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151 if year>=2002
outreg2 using Regression_Output/rspendgdptable3.doc, append: reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot foral




***********NEW MODEL, WITH DISCRETIONARY SPENDING AS DEPENDENT VARIABLE
**BASIC REGRESSIONS FOR DISCRETIONARY SPENDING/GDP
clear
use ./FinalData/final.dta
set more off

*CHECKING FOR CORRELATION
corr rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot

*TABLE 13
capture mkdir ./Regression_Output
outreg2 using Regression_Output/discgdptable.doc, replace: reg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region) robust

capture mkdir ./Regression_Output
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot interest, absorb(region) robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot inf, absorb(region) robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ndefgdp, absorb(region) robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ncons, absorb(region) robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: areg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot crisis, absorb(region) robust

outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: reg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot lang, robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: reg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151, robust
outreg2 using Regression_Output/discgdptable.doc, ctitle("discgdp w/ Region FE") append: reg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot foral, robust




**BASIC REGRESSIONS FOR DISCRETIONARY SPENDING/DISCRETIONARY FUNDS
clear
use ./FinalData/final.dta
set more off

*CHECKING FOR CORRELATION
corr rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot

*TABLE 14
capture mkdir ./Regression_Output
outreg2 using Regression_Output/discfundstable.doc, replace: reg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot, absorb(region) robust

capture mkdir ./Regression_Output
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot interest, absorb(region) robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot inf, absorb(region) robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ndefgdp, absorb(region) robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot ncons, absorb(region) robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: areg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot crisis, absorb(region) robust

capture mkdir ./Regression_Output
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: reg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot lang, robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: reg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot art151, robust
outreg2 using Regression_Output/discfundstable.doc, ctitle("discfunds w/ Region FE") append: reg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot foral, robust


*****CHECK FOR AUTOCORRELATION USING DURBIN-WATSON TEST OR BREUSCH-PAGAN HETTEST
tsset region year

forvalues ca=1/17{
	quietly reg rdefgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot if region==`ca'
	estat dwatson
}


forvalues ca=1/17{
	quietly reg rdefgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot if region==`ca'
	estat dwatson
}


forvalues ca=1/17{
	quietly reg rspendgdp rgdpcap rgdpgrowth coa minority largest newgovt elec elec_1 elec_3 rcons transtot if region==`ca'
	estat dwatson
}


forvalues ca=1/17{
	quietly reg rspendgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot if region==`ca'
	estat dwatson
}


quietly reg discgdp rincgdp rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
estat hettest


quietly reg discfunds rgdpcap rgdpgrowth rgdpgrowthl1 rgdpgrowthl2 rgdpgrowthl3 coa minority largest newgovt elec elec_1 elec_3 rcons transtot
estat hettest

*****************************
********DATA APPENDIX********


**RDEFGDP
clear
use ./FinalData/final.dta
set more off
drop if year>2010 | year<1984

sum rdefgdp, d

table year, contents(mean rdefgdp max rdefgdp min rdefgdp)
graph hbox rdefgdp, over(year)

table regname, contents(mean rdefgdp max rdefgdp min rdefgdp)
graph hbox rdefgdp, over(regname)

hist rdefgdp


**RINCGDP
clear
use ./FinalData/final.dta
set more off
drop if year>2010 | year<1984

sum rincgdp, d

table year, contents(mean rincgdp max rincgdp min rincgdp)
graph hbox rincgdp, over(year)

table regname, contents(mean rincgdp max rincgdp min rincgdp)
graph hbox rincgdp, over(regname)

hist rincgdp


**RSPENDGDP
clear
use ./FinalData/final.dta
set more off
drop if year>2010 | year<1984

sum rspendgdp, d

table year, contents(mean rspendgdp max rspendgdp min rspendgdp)
graph hbox rspendgdp, over(year)

table regname, contents(mean rspendgdp max rspendgdp min rspendgdp)
graph hbox rspendgdp, over(regname)

hist rspendgdp


**RGDPGROWTH
clear
use ./FinalData/final.dta
set more off
drop if year>2010 | year<1984

sum rgdpgrowth, d

table year, contents(mean rgdpgrowth max rgdpgrowth min rgdpgrowth)
graph hbox rgdpgrowth, over(year)

table regname, contents(mean rgdpgrowth max rgdpgrowth min rgdpgrowth)
graph hbox rgdpgrowth, over(regname)

hist rgdpgrowth


**DISCTOT
clear
use ./FinalData/final.dta
set more off
drop if year<2002 | year>2010

sum disctot, d

table year, contents(mean disctot max disctot min disctot)
graph hbox disctot, over(year)

table regname, contents(mean disctot max disctot min disctot)
graph hbox disctot, over(regname)

hist disctot


**DISCGDP
clear
use ./FinalData/final.dta
set more off
drop if year<2002 | year>2010

sum discgdp, d

table year, contents(mean discgdp max discgdp min discgdp)
graph hbox discgdp, over(year)

table regname, contents(mean discgdp max discgdp min discgdp)
graph hbox discgdp, over(regname)

hist discgdp


**DISCFUNDS
clear
use ./FinalData/final.dta
set more off
drop if year<2002 | year>2010

sum discfunds, d

table year, contents(mean discfunds max discfunds min discfunds)
graph hbox discfunds, over(year)

table regname, contents(mean discfunds max discfunds min discfunds)
graph hbox discfunds, over(regname)

hist discfunds


**TRANSTOT
clear
use ./FinalData/final.dta
set more off
drop if year<1984 | year>2010

sum transtot, d

table year, contents(mean transtot max transtot min transtot)
graph hbox transtot, over(year)

table regname, contents(mean transtot max transtot min transtot)
graph hbox transtot, over(regname)

hist transtot


**TRANSGDP
clear
use ./FinalData/final.dta
set more off
drop if year<1983 | year>2010

sum transgdp, d

table year, contents(mean transgdp max transgdp min transgdp)
graph hbox transgdp, over(year)

table regname, contents(mean transgdp max transgdp min transgdp)
graph hbox transgdp, over(regname)

hist transgdp


**INTEREST
clear
use ./FinalData/final.dta
set more off
drop if year<1983

sum interest, d

sort year
by year: egen ym_in=mean(interest)
scatter ym_in year, c(l) s(i) lwidth(thick) title("Interest Rate on 10-Year Gov't Note") ytitle("Interest Rate") xtitle("Year") xlabel(1983(10)2013)

hist interest


**INF
clear
use ./FinalData/final.dta
set more off

sum inf, d

sort year
scatter inf year, c(l) s(i) lwidth(thick) title("Rate of Inflation") ytitle("Inflation Rate") xtitle("Year") xlabel(1983(10)2013)

hist inf


**NDEFGDP
clear
use ./FinalData/final.dta
set more off
drop if year<1985 | year>2010

sum ndefgdp, d

sort year
by year: egen ym_ndef=mean(ndefgdp)
scatter ym_ndef year, c(l) s(i) title("National Deficit/GDP by Year") ytitle("Deficit/GDP") xtitle("Year") xlabel(1983(10)2013) legend(label(1 "Federal Deficit/GDP"))

hist ndefgdp


**NSPENDGDP
clear
use ./FinalData/final.dta
set more off

sum nspendgdp, d

sort year
by year: egen ym_nspend=mean(nspendgdp)
scatter ym_nspend year, c(l) s(i) title("National Spending/GDP") ytitle("Spending/GDP") xtitle("Year") xlabel(1983(10)2013) legend(label(2 "Federal Spending/GDP"))

hist nspendgdp


**RPARTY
clear
use ./FinalData/final.dta
set more off



*Line graph shows changes in the political balance of power over time
sort year
by year: egen ym_rpp=mean(rpp) if year>=1983
by year: replace ym_rpp=. if _n>1
by year: egen ym_rpsoe=mean(rpsoe) if year>=1983
by year: replace ym_rpsoe=. if _n>1
by year: egen ym_rauto=mean(rauto) if year>=1983
by year: replace ym_rauto=. if _n>1
scatter ym_rpsoe ym_rpp ym_rauto year, c(l l l) s(i i i) lpattern(l - _) title("Political Balance of Power over Time") ytitle("Fraction of regions in power") b1title("Year") legend(label(1 "Liberal") label(2 "Conservative") label(3 "Regionalist")) xlabel(1983(10)2013)


*Same graph, except this classifies any regionalist party as either conservative or liberal given their traditional leanings
by year: egen ym_rcons=mean(rcons) if year>=1983 & year<=2012
by year: replace ym_rcons=. if _n>1
by year: egen ym_rlib=mean(rlib) if year>=1983 & year<=2012
by year: replace ym_rlib=. if _n>1

scatter ym_rcon ym_rlib year, c(l l) s(i i) lpattern(l -) title("Political Balance, Classifying Regionalist Parties Lib/Cons") ytitle("Fraction of regions in power") b1title("Year") legend(label(1 "Conservative") label(2 "Liberal")) xlabel(1983(10)2013)


**CYCLE
clear
use ./FinalData/final.dta
set more off

tab cycle



**EURO
clear
use ./FinalData/final.dta
set more off

tab euro if region==1


**POST02
clear
use ./FinalData/final.dta
set more off

tab post02 if region==1


**BSL
clear
use ./FinalData/final.dta
set more off

tab bsl if region==1


**CRISIS
clear
use ./FinalData/final.dta
set more off

tab crisis if region==1


**LANG
clear
use ./FinalData/final.dta
set more off

tab lang if year==2010


**ART151
clear
use ./FinalData/final.dta
set more off

tab art151 if year==2010


**FORAL
clear
use ./FinalData/final.dta
set more off

tab foral if year==2010


**COA
clear
use ./FinalData/final.dta
set more off
drop if year<1983

tab coa


**MINORITY
clear
use ./FinalData/final.dta
set more off

tab minority


**LARGEST
clear
use ./FinalData/final.dta
set more off

tab largest


**NEWGOVT
clear
use ./FinalData/final.dta
set more off

tab newgovt


**BAILOUT
clear
use ./FinalData/final.dta
set more off

tab bailout if year==2010

